function rate = mtneurons(preferred, stimulus, neurons)
% function rate = mtneurons(preferred, stimulus, neurons)
% for stimulus conditions 1:n (n is currently 202), preferred is index of 
% preferred stimulus, stimulus is index of current stimulus, and neurons 
% is the number of neurons with the same preference
% rate is a vector of firing rates for a set of MT neurons with this common 
% direction preference and stimulus conditions (Wallisch p280)

% 202 stimulus conditions with index 1 corresponding to max firing rate
xc = [0:100 101:-1:1];
% scale factor of 1800 gives max firing rate around 30, as in Wallisch
typical_rate_mean = 1800*normpdf(xc,0,24);
nstims = length(typical_rate_mean);
typical_rate_stdev = 1.5*sqrt(typical_rate_mean);
meanV = typical_rate_mean(1 + mod(stimulus-preferred, nstims));
stdev = typical_rate_stdev(1 + mod(stimulus-preferred, nstims));
rate = normrnd(meanV*ones(1,neurons), stdev*ones(1,neurons));  
end
